@@ -66,7 +66,7 @@ import shutil
 import subprocess
 import sys
 import textwrap
-from typing import BinaryIO, Iterator, List, Union
+from typing import BinaryIO, Iterator, List, Optional, Union
 from xml.etree import ElementTree as ElementTree
 # ... cElementTree used to be the fast implementation; now ElementTree is fast
 # and cElementTree is deprecated; see
@@ -82,8 +82,10 @@ import semver
 
 try:
     import chardet
+    from chardet.universaldetector import UniversalDetector
 except ImportError:
     chardet = None
+    UniversalDetector = None
 
 try:
     # noinspection PyPackageRequirements
@@ -226,6 +228,33 @@ def get_file_contents(filename: str = None, blob: bytes = None,
         return f.read()
 
 
+def get_chardet_encoding(binary_contents: bytes) -> Optional[str]:
+    if not binary_contents:
+        return None
+    if not chardet or not UniversalDetector:
+        log.warning("chardet not installed; limits detection of encodings")
+        return None
+    # METHOD 1
+    # http://chardet.readthedocs.io/en/latest/
+    #
+    # guess = chardet.detect(binary_contents)
+    #
+    # METHOD 2: faster with large files
+    # http://chardet.readthedocs.io/en/latest/
+    # http://stackoverflow.com/questions/13857856/split-byte-string-into-lines
+    detector = UniversalDetector()
+    for byte_line in binary_contents.split(b"\n"):
+        detector.feed(byte_line)
+        if detector.done:
+            break
+    guess = detector.result
+    # Handle result
+    if 'encoding' not in guess:
+        log.warning("Something went wrong within chardet; no encoding")
+        return None
+    return guess['encoding']
+
+
 def get_file_contents_text(filename: str = None, blob: bytes = None,
                            encoding: str = None,
                            **kwargs) -> str:
