@@ -4,7 +4,7 @@
 # See LICENSE for details.
 
 
-VERSION = '0.2.12'
+VERSION = '0.2.13'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -22,7 +22,8 @@ RECENT_VERSION_HISTORY = """
 - 0.2.11, 2017-04-29
   Encoding auto-detection for text extraction from files.
 
-- 0.2.12, 2017-05-02
+- 0.2.12 to 0.2.13, 2017-05-02
   More file types support for simple text extraction.
+  Better encoding support.
 
 """
